Skip to contents

Read-only snapshot of the built-in prolfqua facade registry, taken at package load time. It is derived from the single source of truth (.seed_facade_registry()); use register_facade to add entries from downstream packages, lookup_facade to resolve a single entry, and list_facades() to enumerate the live registry (which reflects downstream registrations).

Usage

FACADE_REGISTRY

Format

An object of class facade_registry (inherits from list) of length 19.

Value

A named list of built-in facade registry entries.

Details

Each entry has fields class, needs, package, and needs_saint_annotation.

Examples

names(FACADE_REGISTRY)
#>  [1] "binomial_nested"   "deqms"             "deqms_voom"       
#>  [4] "firth"             "firth_nested"      "limma"            
#>  [7] "limma_impute"      "limma_voom"        "limma_voom_impute"
#> [10] "limpa"             "limpa_nested"      "lm"               
#> [13] "lm_impute"         "lm_missing"        "lmer_nested"      
#> [16] "rfit"              "rfit_impute"       "rlm"              
#> [19] "ropeca_nested"    
FACADE_REGISTRY$limma$class
#> [1] "ContrastsLimmaFacade"