Skip to contents

Analysis Configuration — holds all table annotations, hierarchy definitions, factor definitions, and analysis parameters in a single flat object.

Public fields

sep

separator to use when uniting columns is necessary

file_name

column name of column containing raw file names

sample_name

(will be generated from factors or file_name)

norm_value

optional column with normalization values (e.g., Creatinine)

isotope_label

which column contains the isotope label (e.g. heavy or light), or light only if LFQ.

ident_q_value

column name with identification QValues (smaller better)

ident_score

column with identification score (larger better)

opt_rt

optional column with rt information

opt_mz

optional column with mz information

opt_se

optional column with standard errors (e.g. from limpa aggregation)

nr_children

optional column containing for instance the number of peptides

work_intensity

column which contains the intensities

is_response_transformed

are the intensities transformed for constant variance

bin_resp

column with encoded missing information

factors

Names of columns containing factors (annotations)

factor_depth

number of relevant factors (used by plotting functions etc)

hierarchy

list with columns describing the measurement hierarchy (i.e. protein peptide precursor fragment)

hierarchy_depth

At which depth do you want to model i.e. protein than 1

min_peptides_protein

minimum number of peptides per protein

Methods


Method new()

create AnalysisConfiguration

Usage


Method set_response()

Add name of intensity column

Usage

AnalysisConfiguration$set_response(colName)

Arguments

colName

name of intensity column


Method get_response()

Get name of working intensity column

Usage

AnalysisConfiguration$get_response()


Method pop_response()

Remove last name in array of working intensity column names

Usage

AnalysisConfiguration$pop_response()


Method factor_keys()

Get factor keys

Usage

AnalysisConfiguration$factor_keys()

Returns

array with keys


Method factor_keys_depth()

Get factor keys till factorDepth

Usage

AnalysisConfiguration$factor_keys_depth()


Method hierarchy_keys()

get hierarchy keys

Usage

AnalysisConfiguration$hierarchy_keys(rev = FALSE)

Arguments

rev

return in reverse order

Returns

array of column names


Method hierarchyKeys()

get hierarchy keys (deprecated alias for hierarchy_keys)

Usage

AnalysisConfiguration$hierarchyKeys(rev = FALSE)

Arguments

rev

return in reverse order

Returns

array of column names


Method hierarchy_keys_depth()

get hierarchy keys up to depth

Usage

AnalysisConfiguration$hierarchy_keys_depth(names = TRUE)

Arguments

names

if TRUE names only if FALSE key value pairs

Returns

array of column names


Method hkeysDepth()

get hierarchy keys up to depth (deprecated alias for hierarchy_keys_depth)

Usage

AnalysisConfiguration$hkeysDepth(names = TRUE)

Arguments

names

if TRUE names only if FALSE key value pairs

Returns

array of column names


Method id_required()

Id Columns which must be in the input data frame

Usage

AnalysisConfiguration$id_required()

Returns

character array


Method id_vars()

get names of columns annotating values (e.g. intensities)

Usage

AnalysisConfiguration$id_vars()

Returns

character array


Method value_vars()

get names of columns containing observations e.g. (intensity, qValue, mz or rt)

Usage

AnalysisConfiguration$value_vars()


Method annotation_vars()

get names of columns with sample annotations

Usage

AnalysisConfiguration$annotation_vars()


Method clone()

The objects of this class are cloneable with this method.

Usage

AnalysisConfiguration$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Examples

istar <- sim_lfq_data_peptide_config()
#> creating sampleName from file_name column
#> completing cases
#> completing cases done
#> setup done
config <- istar$config
stopifnot("AnalysisConfiguration" %in% class(config))
stopifnot(length(config$hierarchy_keys()) > 0)
stopifnot(length(config$factor_keys()) > 0)
stopifnot(length(config$get_response()) == 1)