Analysis Configuration — holds all table annotations, hierarchy definitions, factor definitions, and analysis parameters in a single flat object.
Public fields
sepseparator to use when uniting columns is necessary
file_namecolumn name of column containing raw file names
sample_name(will be generated from factors or file_name)
norm_valueoptional column with normalization values (e.g., Creatinine)
isotope_labelwhich column contains the isotope label (e.g. heavy or light), or light only if LFQ.
ident_q_valuecolumn name with identification QValues (smaller better)
ident_scorecolumn with identification score (larger better)
opt_rtoptional column with rt information
opt_mzoptional column with mz information
opt_seoptional column with standard errors (e.g. from limpa aggregation)
nr_childrenoptional column containing for instance the number of peptides
work_intensitycolumn which contains the intensities
is_response_transformedare the intensities transformed for constant variance
bin_respcolumn with encoded missing information
factorsNames of columns containing factors (annotations)
factor_depthnumber of relevant factors (used by plotting functions etc)
hierarchylist with columns describing the measurement hierarchy (i.e. protein peptide precursor fragment)
hierarchy_depthAt which depth do you want to model i.e. protein than 1
min_peptides_proteinminimum number of peptides per protein
Methods
Examples
istar <- sim_lfq_data_peptide_config()
#> creating sampleName from file_name column
#> completing cases
#> completing cases done
#> setup done
config <- istar$config
stopifnot("AnalysisConfiguration" %in% class(config))
stopifnot(length(config$hierarchy_keys()) > 0)
stopifnot(length(config$factor_keys()) > 0)
stopifnot(length(config$get_response()) == 1)