Skip to contents

Read-only snapshot of the built-in prolfqua facade registry, taken at package load time. It is derived from the single source of truth (.seed_facade_registry()); use register_facade to add entries from downstream packages, lookup_facade to resolve a single entry, and list_facades() to enumerate the live registry (which reflects downstream registrations).

Usage

FACADE_REGISTRY

Format

An object of class facade_registry (inherits from list) of length 18.

Details

Each entry has fields class, needs, package, and needs_saint_annotation.

Examples

names(FACADE_REGISTRY)
#>  [1] "deqms"             "deqms_voom"        "firth"            
#>  [4] "firth_nested"      "limma"             "limma_impute"     
#>  [7] "limma_voom"        "limma_voom_impute" "limpa"            
#> [10] "limpa_nested"      "lm"                "lm_impute"        
#> [13] "lm_missing"        "lmer_nested"       "rfit"             
#> [16] "rfit_impute"       "rlm"               "ropeca_nested"    
FACADE_REGISTRY$limma$class
#> [1] "ContrastsLimmaFacade"