A named list mapping short names to facade class names and their data requirements. Each entry has:
- class
Character string naming the R6 facade class
- needs
One of
"aggregated","nested", or"either"
A named list mapping short names to facade class names and their data requirements. Each entry has:
Character string naming the R6 facade class
One of "aggregated", "nested", or "either"