Skip to contents

Count distinct elements for each level of hierarchy per sample

Count distinct elements for each level of hierarchy per sample

Details

Provides wide, long, and plot views of hierarchy counts.

Public fields

.summary

summarised data frame

.configuration

AnalysisConfiguration object

Methods


Method new()

Create a new HierarchyCountsSample

Usage

HierarchyCountsSample$new(pdata, configuration, nr_children = 1)

Arguments

pdata

data frame

configuration

AnalysisConfiguration

nr_children

minimum number of children to include


Method wide()

Return wide-format summary

Usage

HierarchyCountsSample$wide()


Method long()

Return long-format summary

Usage

HierarchyCountsSample$long()


Method plot()

Return barplot of hierarchy counts

Usage

HierarchyCountsSample$plot()


Method clone()

The objects of this class are cloneable with this method.

Usage

HierarchyCountsSample$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.