Encodes missingness as a binary response and fits the peptide-aware Firth logistic backend. Proteins with multiple child features are fitted with the lowest hierarchy key appended to the formula.
Arguments
- lfqdata
nested
LFQDataobject- modelstr
model formula string without the response variable (e.g.
"~ group_")
Value
a ModelFirth object
See also
Other modelling:
Contrasts,
ContrastsDEqMSFacade,
ContrastsFirth,
ContrastsFirthFacade,
ContrastsLMFacade,
ContrastsLMMissingFacade,
ContrastsLimma,
ContrastsLimmaFacade,
ContrastsLmerFacade,
ContrastsMissing,
ContrastsModerated,
ContrastsModeratedDEqMS,
ContrastsPlotter,
ContrastsProDA,
ContrastsROPECA,
ContrastsROPECAFacade,
ContrastsTable,
INTERNAL_FUNCTIONS_BY_FAMILY,
LR_test(),
Model,
ModelFirth,
ModelLimma,
build_contrast_analysis(),
build_model(),
build_model_glm_protein(),
build_model_limma(),
build_model_logistf(),
contrasts_fisher_exact(),
get_anova_df(),
get_complete_model_fit(),
get_p_values_pbeta(),
group_label(),
isSingular_lm(),
linfct_all_possible_contrasts(),
linfct_factors_contrasts(),
linfct_from_model(),
linfct_matrix_contrasts(),
merge_contrasts_results(),
model_analyse(),
model_summary(),
moderated_p_deqms(),
moderated_p_deqms_long(),
moderated_p_limma(),
moderated_p_limma_long(),
my_contest(),
my_contrast(),
my_contrast_V1(),
my_contrast_V2(),
my_glht(),
pivot_model_contrasts_2_Wide(),
plot_lmer_peptide_predictions(),
sim_build_models_lm(),
sim_build_models_lmer(),
sim_build_models_logistf(),
sim_make_model_lm(),
sim_make_model_lmer(),
strategy_limma(),
strategy_logistf(),
summary_ROPECA_median_p.scaled()
Examples
istar <- sim_lfq_data_peptide_config(Nprot = 10, with_missing = TRUE, weight_missing = 0.5, seed = 3)
#> creating sampleName from fileName column
#> completing cases
#> completing cases done
#> setup done
lfqdata <- LFQData$new(istar$data, istar$config)
mod <- build_model_glm_peptide(lfqdata, "~ group_")
#> completing cases
#> Joining with `by = join_by(protein_Id)`
#> Joining with `by = join_by(protein_Id)`
#> Joining with `by = join_by(protein_Id)`
#> Joining with `by = join_by(protein_Id)`
head(mod$get_coefficients())
#> # A tibble: 6 × 11
#> # Groups: protein_Id [2]
#> protein_Id factor Estimate se.coef. lower.0.95 upper.0.95 Chisq p method
#> <chr> <chr> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl>
#> 1 7IZdVV~08… (Inte… 2.10e+ 0 0.950 0.439 4.49 6.53 0.0106 2
#> 2 7IZdVV~08… group… 6.77e- 1 0.786 -0.937 2.51 0.669 0.413 2
#> 3 7IZdVV~08… group… -6.66e- 1 0.645 -2.08 0.640 0.990 0.320 2
#> 4 AZPG26~20… (Inte… 9.05e- 1 0.863 -0.729 2.90 1.15 0.284 2
#> 5 AZPG26~20… group… 2.23e-16 1.02 -2.09 2.09 0 1 2
#> 6 AZPG26~20… group… 1.82e+ 0 1.55 -0.855 6.80 1.67 0.197 2
#> # ℹ 2 more variables: isSingular <lgl>, nrcoef <int>