Skip to contents

Compute Tukey's median polish estimate of a protein from peptide or precursor intensities

Usage

medpolish_estimate(x, name = FALSE, sampleName = "sampleName")

Arguments

x

a matrix

name

if TRUE returns the name of the summary column

Value

data.frame with number of rows equal to number of columns of input matrix.

Examples


medpolish_estimate(name = TRUE)
#> [1] "medpolish"
gg <- matrix(runif(20), 4, 5)
rownames(gg) <- paste0("A", 1:4)
colnames(gg) <- make.names(1:5)
gg
#>           X1        X2        X3        X4        X5
#> A1 0.1729643 0.2074822 0.2092584 0.5467840 0.8926204
#> A2 0.4603666 0.1351013 0.7143354 0.7838502 0.2634550
#> A3 0.5609443 0.2820738 0.5724989 0.7168003 0.4633200
#> A4 0.7814906 0.4122952 0.3613100 0.7561737 0.2200695
mx <- medpolish_estimate(gg)