Skip to contents

Plot peptide intensities of protein as a function of the sample and factor

Usage

plot_hierarchies_line(
  res,
  protein_name,
  lfqdata,
  separate = FALSE,
  show.legend = FALSE
)

Arguments

res

data.frame

protein_name

title of plot

lfqdata

LFQData object

separate

if heavy and light show in one plot or with separate y axis?

Examples



istar <- sim_lfq_data_peptide_config()
#> creating sampleName from file_name column
#> completing cases
#> completing cases done
#> setup done
config <- istar$config
analysis <- istar$data

xnested <- analysis |>
  dplyr::group_by(across(all_of(config$hierarchy_keys_depth()))) |>
  tidyr::nest()

lfq <- LFQData$new(analysis, config)
prolfqua::plot_hierarchies_line(xnested$data[[1]], xnested$protein_Id[[1]], lfq)
#> Warning: Removed 7 rows containing missing values or values outside the scale range
#> (`geom_point()`).
#> Warning: Removed 4 rows containing missing values or values outside the scale range
#> (`geom_line()`).