Fixes pheatmap's print method which omits grid.newpage(),
causing the heatmap to draw on top of the previous plot when
multiple plots are produced in the same knitr chunk or graphics device.
Usage
# S3 method for class 'pheatmap'
print(x, ...)Fixes pheatmap's print method which omits grid.newpage(),
causing the heatmap to draw on top of the previous plot when
multiple plots are produced in the same knitr chunk or graphics device.
# S3 method for class 'pheatmap'
print(x, ...)